@@ -326,3 +326,28 @@ class PodcastIndex:
 
         # Call Api for result
         return self._make_request_get_result_helper(url, payload)
+
+    def addByItunesId(self, itunesId):
+        """
+        Request a podcast be added to the index based on itunesId.
+
+        Args:
+            itunesId (string or integer): Itunes ID for the feed.
+
+        Raises:
+            requests.exceptions.HTTPError: When the status code is not OK.
+
+        Returns:
+            Dict: API response
+        """
+        # Setup request
+        url = self.base_url + "/add/byitunesid"
+
+        # Setup payload
+        payload = {
+            "id": itunesId,
+            "pretty": 1,
+        }
+
+        # Call Api for result
+        return self._make_request_get_result_helper(url, payload)
